================
Welcome to eyeD3
================

.. include:: ../README.rst

Installation
============

Stable releases of eyeD3 are best installed via ``pip`` or ``easy_install``;
or you may download TGZ or ZIP source archives from a couple of official
locations. Detailed instructions and links may be found on the
:doc:`installation` page.

Otherwise, if you want to live on the edge, you can pull down the source code
from the Git repository at `GitHub`_. The :doc:`installation` page has
details for how to access the source code.

.. _GitHub: https://github.com/nicfit/eyeD3

.. toctree::
    :hidden:

    installation

.. _documentation-index:

Documentation
=============

.. toctree::
    :maxdepth: 2

    cli
    compliance
    modules
    contributing
    authors

.. toctree::
    :hidden:

    history


ChangeLog
=========

Changes made to eyeD3 and the project's release history can be found in the
:doc:`history`.

.. _references-index:

References
==========
- ID3 `v1.x Specification <http://id3lib.sourceforge.net/id3/id3v1.html>`_
- ID3 v2.4 `Structure <http://www.id3.org/id3v2.4.0-structure>`_ and
  `Frames <http://www.id3.org/id3v2.4.0-frames>`_ 
- ID3 `v2.3 Specification <http://www.id3.org/id3v2.3.0>`_
- ID3 `v2.2 Specification <http://www.id3.org/id3v2-00>`_
- ISO `8601 Date and Time <http://www.cl.cam.ac.uk/~mgk25/iso-time.html>`_
- ISO `639-2 Language Codes <http://en.wikipedia.org/wiki/ISO_639-2>`_
- MusicBrainz Tag `Mappings <http://wiki.musicbrainz.org/MusicBrainz_Tag>`_
- MP3 `Headers <http://www.mp3-tech.org/programmer/frame_header.html>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
